@@ -195,6 +195,7 @@ class SecurityZoneActivationMode(AutoNameEnum):
 class ClientType(AutoNameEnum):
     APP = auto()
     C2C = auto()
+    SMART_WATCH = auto()
 
 
 class DeviceType(AutoNameEnum):
@@ -202,6 +203,7 @@ class DeviceType(AutoNameEnum):
     BASE_DEVICE = auto()
     EXTERNAL = auto()
     ACCELERATION_SENSOR = auto()
+    ACCESS_POINT = auto()
     ALARM_SIREN_INDOOR = auto()
     ALARM_SIREN_OUTDOOR = auto()
     BLIND_MODULE = auto()
@@ -239,6 +241,8 @@ class DeviceType(AutoNameEnum):
     HEATING_THERMOSTAT_COMPACT = auto()
     HEATING_THERMOSTAT_COMPACT_PLUS = auto()
     HEATING_THERMOSTAT_EVO = auto()
+    HEATING_THERMOSTAT_THREE = auto()
+    HEATING_THERMOSTAT_FLEX = auto()
     HOME_CONTROL_ACCESS_POINT = auto()
     HOERMANN_DRIVES_MODULE = auto()
     KEY_REMOTE_CONTROL_4 = auto()
@@ -247,6 +251,7 @@ class DeviceType(AutoNameEnum):
     MOTION_DETECTOR_INDOOR = auto()
     MOTION_DETECTOR_OUTDOOR = auto()
     MOTION_DETECTOR_PUSH_BUTTON = auto()
+    MOTION_DETECTOR_SWITCH_OUTDOOR = auto()
     MULTI_IO_BOX = auto()
     OPEN_COLLECTOR_8_MODULE = auto()
     PASSAGE_DETECTOR = auto()
@@ -273,12 +278,16 @@ class DeviceType(AutoNameEnum):
     SHUTTER_CONTACT_MAGNETIC = auto()
     SHUTTER_CONTACT_OPTICAL_PLUS = auto()
     SMOKE_DETECTOR = auto()
+    SWITCH_MEASURING_CABLE_OUTDOOR = auto()
     TEMPERATURE_HUMIDITY_SENSOR = auto()
+    TEMPERATURE_HUMIDITY_SENSOR_COMPACT = auto()
     TEMPERATURE_HUMIDITY_SENSOR_DISPLAY = auto()
     TEMPERATURE_HUMIDITY_SENSOR_OUTDOOR = auto()
     TEMPERATURE_SENSOR_2_EXTERNAL_DELTA = auto()
     TILT_VIBRATION_SENSOR = auto()
+    TILT_VIBRATION_SENSOR_COMPACT = auto()
     TORMATIC_MODULE = auto()
+    WALL_MOUNTED_KEY_PAD = auto()
     WALL_MOUNTED_THERMOSTAT_BASIC_HUMIDITY = auto()
     WALL_MOUNTED_THERMOSTAT_PRO = auto()
     WALL_MOUNTED_GARAGE_DOOR_CONTROLLER = auto()
@@ -291,6 +300,7 @@ class DeviceType(AutoNameEnum):
     WIRED_DIMMER_3 = auto()
     WIRED_DIN_RAIL_ACCESS_POINT = auto()
     WIRED_FLOOR_TERMINAL_BLOCK_12 = auto()
+    WIRED_INPUT_16 = auto()
     WIRED_INPUT_32 = auto()
     WIRED_INPUT_SWITCH_6 = auto()
     WIRED_MOTION_DETECTOR_PUSH_BUTTON = auto()
@@ -300,6 +310,8 @@ class DeviceType(AutoNameEnum):
     WIRED_SWITCH_8 = auto()
     WIRED_SWITCH_4 = auto()
     WIRED_WALL_MOUNTED_THERMOSTAT = auto()
+    WIRED_CARBON_TEMPERATURE_HUMIDITY_SENSOR_DISPLAY = auto()
+    WIRELESS_ACCESS_POINT_BASIC = auto()
 
 
 class GroupType(AutoNameEnum):
@@ -307,6 +319,7 @@ class GroupType(AutoNameEnum):
     ACCESS_AUTHORIZATION_PROFILE = auto()
     ACCESS_CONTROL = auto()
     ALARM_SWITCHING = auto()
+    AUTO_RELOCK_PROFILE = auto()
     ENERGY = auto()
     ENVIRONMENT = auto()
     EXTENDED_LINKED_GARAGE_DOOR = auto()
@@ -328,6 +341,8 @@ class GroupType(AutoNameEnum):
     INDOOR_CLIMATE = auto()
     LINKED_SWITCHING = auto()
     LOCK_OUT_PROTECTION_RULE = auto()
+    LOCK_PROFILE = auto()
+    OPEN_DOOR_NOTIFICATION_RULE_GROUP = auto()
     OVER_HEAT_PROTECTION_RULE = auto()
     SECURITY = auto()
     SECURITY_BACKUP_ALARM_SWITCHING = auto()
@@ -436,10 +451,13 @@ class FunctionalChannelType(AutoNameEnum):
     CHANGE_OVER_CHANNEL = auto()
     CARBON_DIOXIDE_SENSOR_CHANNEL = auto()
     CLIMATE_SENSOR_CHANNEL = auto()
+    CODE_PROTECTED_PRIMARY_ACTION_CHANNEL = auto()
+    CODE_PROTECTED_SECONDARY_ACTION_CHANNEL = auto()
     CONTACT_INTERFACE_CHANNEL = auto()
     DEHUMIDIFIER_DEMAND_CHANNEL = auto()
     DEVICE_BASE = auto()
     DEVICE_BASE_FLOOR_HEATING = auto()
+    DEVICE_BLOCKING = auto()
     DEVICE_GLOBAL_PUMP_CONTROL = auto()
     DEVICE_INCORRECT_POSITIONED = auto()
     DEVICE_OPERATIONLOCK = auto()
@@ -490,6 +508,7 @@ class FunctionalChannelType(AutoNameEnum):
     UNIVERSAL_LIGHT_GROUP_CHANNEL = auto()
     WALL_MOUNTED_THERMOSTAT_PRO_CHANNEL = auto()
     WALL_MOUNTED_THERMOSTAT_WITHOUT_DISPLAY_CHANNEL = auto()
+    WALL_MOUNTED_THERMOSTAT_WITH_CARBON_CHANNEL = auto()
     WATER_SENSOR_CHANNEL = auto()
     WEATHER_SENSOR_CHANNEL = auto()
     WEATHER_SENSOR_PLUS_CHANNEL = auto()
@@ -544,6 +563,7 @@ class HumidityValidationType(AutoNameEnum):
 class AccelerationSensorMode(AutoNameEnum):
     ANY_MOTION = auto()
     FLAT_DECT = auto()
+    TILT = auto()
 
 
 class AccelerationSensorNeutralPosition(AutoNameEnum):
@@ -618,6 +638,7 @@ class ConnectionType(AutoNameEnum):
 class DeviceArchetype(AutoNameEnum):
     EXTERNAL = auto()
     HMIP = auto()
+    PLUGIN = auto()
 
 
 class DriveSpeed(AutoNameEnum):
