@@ -1,21 +1,13 @@
-import json
-from datetime import datetime, timedelta, timezone
-from unittest.mock import MagicMock, Mock
-import pytest
-from conftest import utc_offset
-from homematicip.base.base_connection import BaseConnection
+from unittest.mock import Mock
+
 from homematicip.base.channel_event import ChannelEvent
-from homematicip.base.enums import *
 from homematicip.base.functionalChannels import *
 from homematicip.device import *
 from homematicip.home import Home
 from homematicip_demo.helper import (
-    fake_home_download_configuration,
     no_ssl_verification,
 )
 
-from homematicip.class_maps import TYPE_FUNCTIONALCHANNEL_MAP
-
 
 def test_access_controller_channel(fake_home: Home):
     with no_ssl_verification():
@@ -32,12 +24,12 @@ def test_acceleration_sensor_channel(fake_home: Home):
         assert ch.accelerationSensorEventFilterPeriod == 3.0
         assert ch.accelerationSensorMode == AccelerationSensorMode.FLAT_DECT
         assert (
-            ch.accelerationSensorNeutralPosition
-            == AccelerationSensorNeutralPosition.VERTICAL
+                ch.accelerationSensorNeutralPosition
+                == AccelerationSensorNeutralPosition.VERTICAL
         )
         assert (
-            ch.accelerationSensorSensitivity
-            == AccelerationSensorSensitivity.SENSOR_RANGE_4G
+                ch.accelerationSensorSensitivity
+                == AccelerationSensorSensitivity.SENSOR_RANGE_4G
         )
         assert ch.accelerationSensorTriggerAngle == 45
         assert ch.notificationSoundTypeHighToLow == NotificationSoundType.SOUND_LONG
@@ -60,17 +52,17 @@ def test_acceleration_sensor_channel(fake_home: Home):
         assert ch.accelerationSensorEventFilterPeriod == 10.0
         assert ch.accelerationSensorMode == AccelerationSensorMode.ANY_MOTION
         assert (
-            ch.accelerationSensorNeutralPosition
-            == AccelerationSensorNeutralPosition.HORIZONTAL
+                ch.accelerationSensorNeutralPosition
+                == AccelerationSensorNeutralPosition.HORIZONTAL
         )
         assert (
-            ch.accelerationSensorSensitivity
-            == AccelerationSensorSensitivity.SENSOR_RANGE_2G
+                ch.accelerationSensorSensitivity
+                == AccelerationSensorSensitivity.SENSOR_RANGE_2G
         )
         assert ch.accelerationSensorTriggerAngle == 30
         assert ch.notificationSoundTypeHighToLow == NotificationSoundType.SOUND_SHORT
         assert (
-            ch.notificationSoundTypeLowToHigh == NotificationSoundType.SOUND_SHORT_SHORT
+                ch.notificationSoundTypeLowToHigh == NotificationSoundType.SOUND_SHORT_SHORT
         )
 
 
@@ -355,6 +347,20 @@ def test_switch_measuring_channel(fake_home: Home):
         assert ch.on == True
 
 
+def test_switch_measuring_channel_all_attributes(fake_home: Home):
+    with no_ssl_verification():
+        ch = fake_home.search_channel("3014F71100000000000PSMCO", 1)
+        assert isinstance(ch, SwitchMeasuringChannel)
+        assert ch.currentDetectionBehavior == "CURRENTDETECTION_ACTIVE"
+        assert ch.currentPowerConsumption == -0.1
+        assert ch.energyCounter == 0.006500000000000001
+        assert ch.energyCounterTwo == 17.299599999999998
+        assert ch.energyCounterTwoType == "ENERGY_COUNTER_INPUT_SINGLE_TARIFF"
+        assert ch.energyMeterMode == "CONSUMPTION_MEASURING"
+        assert ch.powerMeasuringCategory == "OTHER"
+        assert ch.powerUpSwitchState == "PERMANENT_ON"
+
+
 def test_tilt_vibration_sensor_channel(fake_home: Home):
     with no_ssl_verification():
         ch = fake_home.search_channel("3014F7110TILTVIBRATIONSENSOR", 1)
@@ -363,12 +369,12 @@ def test_tilt_vibration_sensor_channel(fake_home: Home):
         assert ch.accelerationSensorEventFilterPeriod == 0.5
         assert ch.accelerationSensorMode == AccelerationSensorMode.FLAT_DECT
         assert (
-            ch.accelerationSensorNeutralPosition
-            == AccelerationSensorNeutralPosition.VERTICAL
+                ch.accelerationSensorNeutralPosition
+                == AccelerationSensorNeutralPosition.VERTICAL
         )
         assert (
-            ch.accelerationSensorSensitivity
-            == AccelerationSensorSensitivity.SENSOR_RANGE_2G
+                ch.accelerationSensorSensitivity
+                == AccelerationSensorSensitivity.SENSOR_RANGE_2G
         )
         assert ch.accelerationSensorTriggerAngle == 45
         assert ch.accelerationSensorTriggered == True
@@ -385,8 +391,8 @@ def test_tilt_vibration_sensor_channel(fake_home: Home):
         assert ch.accelerationSensorEventFilterPeriod == 10.0
         assert ch.accelerationSensorMode == AccelerationSensorMode.ANY_MOTION
         assert (
-            ch.accelerationSensorSensitivity
-            == AccelerationSensorSensitivity.SENSOR_RANGE_4G
+                ch.accelerationSensorSensitivity
+                == AccelerationSensorSensitivity.SENSOR_RANGE_4G
         )
         assert ch.accelerationSensorTriggerAngle == 30
 
@@ -407,6 +413,19 @@ def test_wall_mounted_thermostate_pro_channel(fake_home: Home):
         assert ch.display == ClimateControlDisplay.ACTUAL
 
 
+def test_wall_mounted_thermostate_with_carbon_dioxide_sensor_channel(fake_home: Home):
+    with no_ssl_verification():
+        ch = fake_home.search_channel("3014F71100000000000SCTHD", 1)
+        assert ch.actualTemperature == 22.5
+        assert ch.carbonDioxideConcentration == 540.0
+        assert ch.channelRole == "WALL_MOUNTED_THERMOSTAT"
+        assert ch.display == ClimateControlDisplay.ACTUAL
+        assert ch.humidity == 41
+        assert ch.setPointTemperature == 22.5
+        assert ch.temperatureOffset == 0.0
+        assert ch.vaporAmount == 8.169998811318226
+
+
 def test_water_sensor_channel(fake_home: Home):
     with no_ssl_verification():
         ch = fake_home.search_channel("3014F7110000000000000050", 1)
@@ -429,13 +448,14 @@ def test_water_sensor_channel(fake_home: Home):
         d = fake_home.search_channel("3014F7110000000000000050", 1)
         assert ch.acousticAlarmTiming == AcousticAlarmTiming.SIX_MINUTES
         assert (
-            ch.acousticAlarmSignal == AcousticAlarmSignal.FREQUENCY_ALTERNATING_LOW_HIGH
+                ch.acousticAlarmSignal == AcousticAlarmSignal.FREQUENCY_ALTERNATING_LOW_HIGH
         )
         assert ch.acousticWaterAlarmTrigger == WaterAlarmTrigger.NO_ALARM
         assert ch.inAppWaterAlarmTrigger == WaterAlarmTrigger.MOISTURE_DETECTION
         assert ch.sirenWaterAlarmTrigger == WaterAlarmTrigger.NO_ALARM
 
-def test_universal_light_channel(fake_home: Home):
+
+async def test_universal_light_channel(fake_home: Home):
     with no_ssl_verification():
         ch = fake_home.search_channel("3014F711000000000000RGBW", 1)
         assert isinstance(ch, UniversalLightChannel)
@@ -448,6 +468,9 @@ def test_universal_light_channel(fake_home: Home):
         assert ch.hue is None
         assert ch.lightSceneId == 0
 
+        await ch.start_light_scene_async(2, 0.8)
+
+
 
 def test_universal_light_group_channel(fake_home: Home):
     with no_ssl_verification():
@@ -461,9 +484,44 @@ def test_door_bell_channel_event(fake_home: Home):
     with no_ssl_verification():
         handler = Mock()
         ch = fake_home.search_channel("3014F7110000000000DSDPCB", 1)
-        channel_event = ChannelEvent(channelEventType="DOOR_BELL_SENSOR_EVENT", channelIndex=1, deviceId=ch.device.id)
+        channel_event = ChannelEvent()
+        channel_event.from_json(
+            {
+                "pushEventType": "DEVICE_CHANNEL_EVENT",
+                "deviceId": "3014F7110000000000DSDPCB",
+                "channelIndex": 1,
+                "channelEventType": "DOOR_BELL_SENSOR_EVENT",
+                "functionalChannelIndex": 1,
+            }
+        )
         ch.add_on_channel_event_handler(handler)
 
         ch.fire_channel_event(channel_event)
 
-        handler.assert_called_once_with(channel_event)
\ No newline at end of file
+        handler.assert_called_once_with(channel_event)
+
+
+def test_channel_role_read(fake_home: Home):
+    with no_ssl_verification():
+        ch = fake_home.search_channel("3014F7110000000000DSDPCB", 1)
+        assert ch.channelRole == "DOOR_BELL_INPUT"
+
+def test_code_protected_primary_channel(fake_home: Home):
+    with no_ssl_verification():
+        ch = fake_home.search_channel("3014F7110000000000000WKP", 7)
+
+        assert isinstance(ch, CodeProtectedPrimaryActionChannel)
+        assert ch.actionCodeConfigured is False
+        assert ch.actionParameter == "NOT_CUSTOMISABLE"
+        assert ch.authorized is True
+
+def test_code_protected_secondary_channel(fake_home: Home):
+    with no_ssl_verification():
+        ch = fake_home.search_channel("3014F7110000000000000WKP", 8)
+
+        assert isinstance(ch, CodeProtectedSecondaryActionChannel)
+
+def test_device_blocking_channel(fake_home: Home):
+    with no_ssl_verification():
+        ch = fake_home.search_channel("3014F7110000000000000WKP", 0)
+        assert isinstance(ch, DeviceBlockingChannel)
\ No newline at end of file
